Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(359)

Unified Diff: chrome/browser/chromeos/login/users/avatar/user_image_manager_impl.h

Issue 718673002: New user type introduced. Combines regular and supervised features. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Logical expression fixed. Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/users/avatar/user_image_manager_impl.h
diff --git a/chrome/browser/chromeos/login/users/avatar/user_image_manager_impl.h b/chrome/browser/chromeos/login/users/avatar/user_image_manager_impl.h
index 03ffc8fa41f4a0b69590d2111c2384318572c4a5..ce442a7f3a24bd7d5c973507cfe0367e8b881899 100644
--- a/chrome/browser/chromeos/login/users/avatar/user_image_manager_impl.h
+++ b/chrome/browser/chromeos/login/users/avatar/user_image_manager_impl.h
@@ -149,8 +149,8 @@ class UserImageManagerImpl
// Returns mutable version of user with |user_id_|.
user_manager::User* GetUserAndModify() const;
- // Returns true if user with |user_id_| is logged in and a regular user.
- bool IsUserLoggedInAndRegular() const;
+ // Returns true if user with |user_id_| is logged in and has gaia account.
bartfab (slow) 2014/11/27 12:51:50 Nit: s/has/has a/
+ bool IsUserLoggedInAndHasGaiaAccount() const;
// The user manager.
user_manager::UserManager* user_manager_;

Powered by Google App Engine
This is Rietveld 408576698